@@ -14,10 +14,9 @@
 #'   and should contain some or all of the the following columns:
 #' - *statistic*: the numeric value of a statistic.
 #' - *df.error*: the numeric value of a parameter being modeled (often degrees
-#' of freedom for the test); note that if there are no degrees of freedom (e.g.,
-#' for non-parametric tests), this column will be irrelevant.
-#' - *df*: relevant only if the statistic in question has two degrees of freedom.
-#' - *p.value*: the two-sided *p*-value associated with the observed statistic.
+#' of freedom for the test); irrelevant. if there are no degrees of freedom.
+#' - *df*: relevant if the statistic in question has two degrees of freedom.
+#' - *p.value*: the two-sided *p*-value associated with observed statistic.
 #' - *method*: method describing the test carried out.
 #' - *effectsize*: name of the effect size (if not present, same as `method`).
 #' - *estimate*: estimated value of the effect size.
@@ -29,8 +28,8 @@
 #'   For example, for tests with *t*-statistic, `statistic.text = "t"`.
 #' @param effsize.text A character that specifies the relevant effect size or
 #'   posterior estimate.
-#' @param digits,digits.df,digits.df.error Number of decimal places to display for the
-#'   parameters (default: `0L`).
+#' @param digits,digits.df,digits.df.error Number of decimal places to display
+#'   for the parameters (default: `0L`).
 #' @param n An integer specifying the sample size used for the test.
 #' @param n.text A character that specifies the design, which will determine
 #'   what the `n` stands for. It defaults to `quote(italic("n")["pairs"])` if
@@ -71,6 +70,9 @@
 #'   digits         = 3L,
 #'   digits.df      = 3L
 #' )
+#'
+#' @template citation
+#'
 #' @export
 add_expression_col <- function(
     data,
@@ -101,8 +103,8 @@ add_expression_col <- function(
   df_expr <- data %>% # convert needed columns to character type
     .data_to_char(digits, digits.df, digits.df.error) %>%
     mutate(
-      statistic.text     = statistic.text %||% stat_text_switch(tolower(method)),
-      es.text            = effsize.text %||% estimate_type_switch(tolower(effectsize)),
+      statistic.text     = statistic.text %||% extract_statistic_text(tolower(method)),
+      es.text            = effsize.text %||% extract_estimate_type(tolower(effectsize)),
       prior.distribution = prior_switch(tolower(method)),
       n.obs              = .prettyNum(n.obs)
     )
